from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BotRequest(_message.Message):
    __slots__ = ("db_auth",)
    DB_AUTH_FIELD_NUMBER: _ClassVar[int]
    db_auth: str
    def __init__(self, db_auth: _Optional[str] = ...) -> None: ...

class GlobalStatusData(_message.Message):
    __slots__ = ("bot_id", "total_tether_volume", "total_revenue", "total_finished_transaction_count", "total_bid_krw", "total_ask_krw", "current_price", "krw_gain_per_finished_transaction", "current_krw")
    BOT_ID_FIELD_NUMBER: _ClassVar[int]
    TOTAL_TETHER_VOLUME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_REVENUE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FINISHED_TRANSACTION_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_BID_KRW_FIELD_NUMBER: _ClassVar[int]
    TOTAL_ASK_KRW_FIELD_NUMBER: _ClassVar[int]
    CURRENT_PRICE_FIELD_NUMBER: _ClassVar[int]
    KRW_GAIN_PER_FINISHED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    CURRENT_KRW_FIELD_NUMBER: _ClassVar[int]
    bot_id: str
    total_tether_volume: float
    total_revenue: float
    total_finished_transaction_count: int
    total_bid_krw: int
    total_ask_krw: int
    current_price: int
    krw_gain_per_finished_transaction: float
    current_krw: int
    def __init__(self, bot_id: _Optional[str] = ..., total_tether_volume: _Optional[float] = ..., total_revenue: _Optional[float] = ..., total_finished_transaction_count: _Optional[int] = ..., total_bid_krw: _Optional[int] = ..., total_ask_krw: _Optional[int] = ..., current_price: _Optional[int] = ..., krw_gain_per_finished_transaction: _Optional[float] = ..., current_krw: _Optional[int] = ...) -> None: ...

class BotTradeMetadata(_message.Message):
    __slots__ = ("bot_id", "ask_exact", "ask_human_readable", "bid_exact", "bid_human_readable")
    BOT_ID_FIELD_NUMBER: _ClassVar[int]
    ASK_EXACT_FIELD_NUMBER: _ClassVar[int]
    ASK_HUMAN_READABLE_FIELD_NUMBER: _ClassVar[int]
    BID_EXACT_FIELD_NUMBER: _ClassVar[int]
    BID_HUMAN_READABLE_FIELD_NUMBER: _ClassVar[int]
    bot_id: str
    ask_exact: str
    ask_human_readable: str
    bid_exact: str
    bid_human_readable: str
    def __init__(self, bot_id: _Optional[str] = ..., ask_exact: _Optional[str] = ..., ask_human_readable: _Optional[str] = ..., bid_exact: _Optional[str] = ..., bid_human_readable: _Optional[str] = ...) -> None: ...

class BotConnectivity(_message.Message):
    __slots__ = ("backend", "upbit")
    BACKEND_FIELD_NUMBER: _ClassVar[int]
    UPBIT_FIELD_NUMBER: _ClassVar[int]
    backend: str
    upbit: str
    def __init__(self, backend: _Optional[str] = ..., upbit: _Optional[str] = ...) -> None: ...

class BotStatChange(_message.Message):
    __slots__ = ("status_code", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    message: str
    def __init__(self, status_code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from tetherhelix_grpc import transaction_pb2 as tetherhelix__grpc_dot_transaction__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in tetherhelix_grpc/transaction_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TransactionStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCurrentTransactions = channel.unary_unary(
                '/tetherhelix_grpc.Transaction/GetCurrentTransactions',
                request_serializer=tetherhelix__grpc_dot_transaction__pb2.TransactionRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_transaction__pb2.TransactionsResponse.FromString,
                _registered_method=True)
        self.GetPastTransactions = channel.unary_unary(
                '/tetherhelix_grpc.Transaction/GetPastTransactions',
                request_serializer=tetherhelix__grpc_dot_transaction__pb2.ScopedTransactionRequest.SerializeToString,
                response_deserializer=tetherhelix__grpc_dot_transaction__pb2.TransactionsResponse.FromString,
                _registered_method=True)


class TransactionServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCurrentTransactions(self, request, context):
        """1. 현재 보유 포지션 조회 (단일 요청-응답)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPastTransactions(self, request, context):
        """2. 과거 포지션 내역 조회 (단일 요청-응답)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TransactionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCurrentTransactions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentTransactions,
                    request_deserializer=tetherhelix__grpc_dot_transaction__pb2.TransactionRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_transaction__pb2.TransactionsResponse.SerializeToString,
            ),
            'GetPastTransactions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPastTransactions,
                    request_deserializer=tetherhelix__grpc_dot_transaction__pb2.ScopedTransactionRequest.FromString,
                    response_serializer=tetherhelix__grpc_dot_transaction__pb2.TransactionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'tetherhelix_grpc.Transaction', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('tetherhelix_grpc.Transaction', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Transaction(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCurrentTransactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.Transaction/GetCurrentTransactions',
            tetherhelix__grpc_dot_transaction__pb2.TransactionRequest.SerializeToString,
            tetherhelix__grpc_dot_transaction__pb2.TransactionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPastTransactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/tetherhelix_grpc.Transaction/GetPastTransactions',
            tetherhelix__grpc_dot_transaction__pb2.ScopedTransactionRequest.SerializeToString,
            tetherhelix__grpc_dot_transaction__pb2.TransactionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/tetherbot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/tetherbot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tetherhelix_grpc/tetherbot.proto\x12\x10tetherhelix_grpc\"\x1d\n\nBotRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\"\x85\x02\n\x10GlobalStatusData\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\t\x12\x1b\n\x13total_tether_volume\x18\x02 \x01(\x02\x12\x15\n\rtotal_revenue\x18\x03 \x01(\x02\x12(\n total_finished_transaction_count\x18\x04 \x01(\x03\x12\x15\n\rtotal_bid_krw\x18\x05 \x01(\x03\x12\x15\n\rtotal_ask_krw\x18\x06 \x01(\x03\x12\x15\n\rcurrent_price\x18\x07 \x01(\x03\x12)\n!krw_gain_per_finished_transaction\x18\x08 \x01(\x02\x12\x13\n\x0b\x63urrent_krw\x18\t \x01(\x03\"\x80\x01\n\x10\x42otTradeMetadata\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\t\x12\x11\n\task_exact\x18\x02 \x01(\t\x12\x1a\n\x12\x61sk_human_readable\x18\x03 \x01(\t\x12\x11\n\tbid_exact\x18\x04 \x01(\t\x12\x1a\n\x12\x62id_human_readable\x18\x05 \x01(\t\"1\n\x0f\x42otConnectivity\x12\x0f\n\x07\x62\x61\x63kend\x18\x01 \x01(\t\x12\r\n\x05upbit\x18\x02 \x01(\t\"5\n\rBotStatChange\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t2\x9d\x03\n\tTetherBot\x12S\n\x0fGetGlobalStatus\x12\x1c.tetherhelix_grpc.BotRequest\x1a\".tetherhelix_grpc.GlobalStatusData\x12R\n\x0eGetBotMetaData\x12\x1c.tetherhelix_grpc.BotRequest\x1a\".tetherhelix_grpc.BotTradeMetadata\x12X\n\x15GetConnectivityStatus\x12\x1c.tetherhelix_grpc.BotRequest\x1a!.tetherhelix_grpc.BotConnectivity\x12\x46\n\x05Start\x12\x1c.tetherhelix_grpc.BotRequest\x1a\x1f.tetherhelix_grpc.BotStatChange\x12\x45\n\x04Stop\x12\x1c.tetherhelix_grpc.BotRequest\x1a\x1f.tetherhelix_grpc.BotStatChangeB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.tetherbot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_BOTREQUEST']._serialized_start=54
  _globals['_BOTREQUEST']._serialized_end=83
  _globals['_GLOBALSTATUSDATA']._serialized_start=86
  _globals['_GLOBALSTATUSDATA']._serialized_end=347
  _globals['_BOTTRADEMETADATA']._serialized_start=350
  _globals['_BOTTRADEMETADATA']._serialized_end=478
  _globals['_BOTCONNECTIVITY']._serialized_start=480
  _globals['_BOTCONNECTIVITY']._serialized_end=529
  _globals['_BOTSTATCHANGE']._serialized_start=531
  _globals['_BOTSTATCHANGE']._serialized_end=584
  _globals['_TETHERBOT']._serialized_start=587
  _globals['_TETHERBOT']._serialized_end=1000
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tetherhelix_grpc/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tetherhelix_grpc/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"tetherhelix_grpc/transaction.proto\x12\x10tetherhelix_grpc\"\xe2\x02\n\x0fTransactionData\x12\x10\n\x08\x62id_uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x62id_created_at\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x0f\n\x07\x62id_krw\x18\x04 \x01(\x02\x12\x0f\n\x07\x62id_fee\x18\x05 \x01(\x02\x12\x12\n\nbid_failed\x18\x06 \x01(\x05\x12\x12\n\nask_failed\x18\x07 \x01(\x05\x12\x14\n\x0corder_status\x18\x08 \x01(\x05\x12\x15\n\rtether_volume\x18\t \x01(\x02\x12\x15\n\rbid_filled_at\x18\n \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x0b \x01(\t\x12\x16\n\x0e\x61sk_created_at\x18\x0c \x01(\t\x12\x15\n\rask_filled_at\x18\r \x01(\t\x12\x11\n\task_price\x18\x0e \x01(\x02\x12\x0f\n\x07\x61sk_fee\x18\x0f \x01(\t\x12\x0f\n\x07revenue\x18\x10 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x11 \x01(\t\"G\n\x12TransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12\x10\n\x08order_by\x18\x03 \x01(\t\"s\n\x18ScopedTransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x03\x12\x10\n\x08order_by\x18\x05 \x01(\t\"O\n\x14TransactionsResponse\x12\x37\n\x0ctransactions\x18\x01 \x03(\x0b\x32!.tetherhelix_grpc.TransactionData2\xe0\x01\n\x0bTransaction\x12\x66\n\x16GetCurrentTransactions\x12$.tetherhelix_grpc.TransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponse\x12i\n\x13GetPastTransactions\x12*.tetherhelix_grpc.ScopedTransactionRequest\x1a&.tetherhelix_grpc.TransactionsResponseB\x08Z\x06proto/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tetherhelix_grpc.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\006proto/'
  _globals['_TRANSACTIONDATA']._serialized_start=57
  _globals['_TRANSACTIONDATA']._serialized_end=411
  _globals['_TRANSACTIONREQUEST']._serialized_start=413
  _globals['_TRANSACTIONREQUEST']._serialized_end=484
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_start=486
  _globals['_SCOPEDTRANSACTIONREQUEST']._serialized_end=601
  _globals['_TRANSACTIONSRESPONSE']._serialized_start=603
  _globals['_TRANSACTIONSRESPONSE']._serialized_end=682
  _globals['_TRANSACTION']._serialized_start=685
  _globals['_TRANSACTION']._serialized_end=909
# @@protoc_insertion_point(module_scope)
